ProviderCreateError

Enum ProviderCreateError 

pub enum ProviderCreateError {
    Unavailable {
        reason: String,
        source: Option<Arc<dyn Error + Send + Sync + 'static>>,
    },
    Failed {
        reason: String,
        source: Option<Arc<dyn Error + Send + Sync + 'static>>,
    },
}
Error returned by one provider while creating a service.

Variants



Unavailable

The provider discovered at creation time that it cannot be used.

Fields

reason: String

Human-readable unavailability reason.

source: Option<Arc<dyn Error + Send + Sync + 'static>>

Lower-level cause, when the provider can expose one.



Failed

The provider failed while creating the service.

Fields

reason: String

Human-readable failure reason.

source: Option<Arc<dyn Error + Send + Sync + 'static>>

Lower-level cause, when the provider can expose one.

Implementations

Source

impl ProviderCreateError

pub fn unavailable(reason: &str) -> Self

Creates an unavailable-provider error.

Parameters
  • reason: Human-readable unavailability reason.
Returns

Provider creation error.

pub fn unavailable_with_source<E>(reason: &str, source: E) -> Self
where E: Error + Send + Sync + 'static,

Creates an unavailable-provider error with a source error.

Parameters
  • reason: Human-readable unavailability reason.
  • source: Lower-level cause that made the provider unavailable.
Returns

Provider creation error preserving the supplied source.

pub fn failed(reason: &str) -> Self

Creates a provider failure error.

Parameters
  • reason: Human-readable failure reason.
Returns

Provider creation error.

pub fn failed_with_source<E>(reason: &str, source: E) -> Self
where E: Error + Send + Sync + 'static,

Creates a provider failure error with a source error.

Parameters
  • reason: Human-readable failure reason.
  • source: Lower-level cause that made service creation fail.
Returns

Provider creation error preserving the supplied source.

pub fn reason(&self) -> &str

Gets the provider-level reason.

Returns

Human-readable reason carried by this error.