ProviderFailure

Enum ProviderFailure 

pub enum ProviderFailure {
    UnknownProvider {
        name: ProviderName,
    },
    Unavailable {
        name: ProviderName,
        source: ProviderCreateError,
    },
    CreateFailed {
        name: ProviderName,
        source: ProviderCreateError,
    },
}
Failure recorded for one provider candidate.

Variants



UnknownProvider

No provider matched the candidate name.

Fields

name: ProviderName

Candidate provider name.



Unavailable

A provider matched the candidate name but is unavailable.

Fields

name: ProviderName

Candidate provider name.

source: ProviderCreateError

Provider-level unavailability error.



CreateFailed

A provider matched the candidate name but failed while creating a service.

Fields

name: ProviderName

Candidate provider name.

source: ProviderCreateError

Provider-level creation error.

Implementations

Source

impl ProviderFailure

pub fn unknown(name: &str) -> Result<Self, ProviderRegistryError>

Creates an unknown-provider failure.

Parameters
  • name: Candidate provider name.
Returns

Unknown-provider failure.

pub fn unavailable( name: &str, reason: &str, ) -> Result<Self, ProviderRegistryError>

Creates an unavailable-provider failure.

Parameters
  • name: Candidate provider name.
  • reason: Human-readable unavailability reason.
Returns

Unavailable-provider failure.

pub fn create_failed( name: &str, reason: &str, ) -> Result<Self, ProviderRegistryError>

Creates a provider-creation failure.

Parameters
  • name: Candidate provider name.
  • reason: Human-readable creation failure reason.
Returns

Provider-creation failure.

pub fn unavailable_from_error( name: &str, source: ProviderCreateError, ) -> Result<Self, ProviderRegistryError>

Creates an unavailable-provider failure from a provider-level error.

Parameters
  • name: Candidate provider name.
  • source: Provider-level unavailability error.
Returns

Unavailable-provider failure preserving the source error.

Errors

Returns ProviderRegistryError when name is not valid.

pub fn create_failed_from_error( name: &str, source: ProviderCreateError, ) -> Result<Self, ProviderRegistryError>

Creates a provider-creation failure from a provider-level error.

Parameters
  • name: Candidate provider name.
  • source: Provider-level creation error.
Returns

Provider-creation failure preserving the source error.

Errors

Returns ProviderRegistryError when name is not valid.

pub fn name(&self) -> &str

Gets the candidate provider name.

Returns

Candidate name associated with this failure.

pub fn provider_name(&self) -> &ProviderName

Gets the candidate provider name.

Returns

Candidate name associated with this failure.