ProviderRegistryError

Enum ProviderRegistryError 

pub enum ProviderRegistryError {
    EmptyProviderName,
    InvalidProviderName {
        name: String,
        reason: String,
    },
    DuplicateProviderName {
        name: ProviderName,
    },
    UnknownProvider {
        name: ProviderName,
    },
    ProviderUnavailable {
        name: ProviderName,
        source: ProviderCreateError,
    },
    ProviderCreate {
        name: ProviderName,
        source: ProviderCreateError,
    },
    NoAvailableProvider {
        failures: Vec<ProviderFailure>,
    },
    EmptyRegistry,
}
Error returned by provider registries.

Variants



EmptyProviderName

A provider id, alias, or selector is empty after trimming.



InvalidProviderName

A provider name contains unsupported characters.

Fields

name: String

Invalid provider name after trimming.

reason: String

Human-readable validation failure reason.



DuplicateProviderName

A provider id or alias conflicts with an already registered name.

Fields

name: ProviderName

Conflicting provider name.



UnknownProvider

No registered provider matches the requested selector.

Fields

name: ProviderName

Requested provider selector.



ProviderUnavailable

The selected provider is not available in the current environment.

Fields

name: ProviderName

Requested provider selector.

source: ProviderCreateError

Provider-level unavailability error.



ProviderCreate

The selected provider failed while creating a service.

Fields

name: ProviderName

Requested provider selector.

source: ProviderCreateError

Provider-level creation error.



NoAvailableProvider

All configured provider candidates failed.

Fields

failures: Vec<ProviderFailure>

Candidate failures in the order they were tried.



EmptyRegistry

No providers are registered.