ProviderSelection

Enum ProviderSelection 

pub enum ProviderSelection {
    Auto,
    Named {
        primary: ProviderName,
        fallbacks: Vec<ProviderName>,
    },
}
Provider candidates used by registry selection.

Variants



Auto

Select providers automatically by registry priority.



Named

Try a primary provider followed by explicit fallback providers.

Fields

primary: ProviderName

Primary provider candidate.

fallbacks: Vec<ProviderName>

Ordered fallback provider candidates.

Implementations

Source

impl ProviderSelection

pub fn auto() -> Self

Creates an automatic provider selection.

Returns

Automatic provider selection.

pub fn named(primary: &str) -> Result<Self, ProviderRegistryError>

Creates a named provider selection without fallbacks.

Parameters
  • primary: Primary provider name.
Returns

Named provider selection.

Errors

Returns ProviderRegistryError when primary is not a valid provider name.

pub fn from_names( primary: &str, fallbacks: &[&str], ) -> Result<Self, ProviderRegistryError>

Creates a named provider selection from borrowed fallback names.

Parameters
  • primary: Primary provider name.
  • fallbacks: Ordered fallback provider names.
Returns

Named provider selection.

Errors

Returns ProviderRegistryError when primary or any fallback is not a valid provider name.

pub fn from_owned_names( primary: &str, fallbacks: &[String], ) -> Result<Self, ProviderRegistryError>

Creates a named provider selection from owned fallback names.

Parameters
  • primary: Primary provider name.
  • fallbacks: Ordered fallback provider names.
Returns

Named provider selection.

Errors

Returns ProviderRegistryError when primary or any fallback is not a valid provider name.

pub fn is_auto(&self) -> bool

Tells whether this selection requests automatic selection.

Returns

true when this selection is ProviderSelection::Auto.

pub fn primary(&self) -> Option<&ProviderName>

Gets the primary provider for named selections.

Returns

Some primary provider for named selections, or None for automatic selection.

pub fn fallbacks(&self) -> &[ProviderName]

Gets ordered fallback provider names.

Returns

Fallback provider names, or an empty slice for automatic selection.