pub struct ProviderDescriptor { /* private fields */ }Expand description
Stable provider metadata used for registration and selection.
Implementations
Sourceimpl ProviderDescriptor
impl ProviderDescriptor
Sourcepub fn new(id: &str) -> Result<Self, ProviderRegistryError>
pub fn new(id: &str) -> Result<Self, ProviderRegistryError>
Creates a descriptor with no aliases and zero priority.
Parameters
id: Provider id.
Returns
Provider descriptor.
Errors
Returns ProviderRegistryError when id is not a valid provider name.
Sourcepub fn with_aliases(
self,
aliases: &[&str],
) -> Result<Self, ProviderRegistryError>
pub fn with_aliases( self, aliases: &[&str], ) -> Result<Self, ProviderRegistryError>
Sets provider aliases.
Parameters
aliases: Provider aliases.
Returns
Updated provider descriptor.
Errors
Returns ProviderRegistryError when any alias is not a valid provider
name, or when aliases duplicate the descriptor id or each other.
Sourcepub fn with_priority(self, priority: i32) -> Self
pub fn with_priority(self, priority: i32) -> Self
Sourcepub fn id(&self) -> &ProviderName
pub fn id(&self) -> &ProviderName
Sourcepub fn aliases(&self) -> &[ProviderName]
pub fn aliases(&self) -> &[ProviderName]
Sourcepub fn aliases_as_str(&self) -> Vec<&str>
pub fn aliases_as_str(&self) -> Vec<&str>